summaryrefslogtreecommitdiff
path: root/sql
diff options
context:
space:
mode:
authorOtto Kekäläinen <otto@kekalainen.net>2020-12-20 21:07:38 +0200
committerDaniel Black <daniel@mariadb.org>2021-03-22 18:10:39 +1100
commitcebf9ee2040195a61fbed32d06cc2e335e9f8dfd (patch)
tree99068da2237fbb33ad57ab920e70332b3832b565 /sql
parente7ddf46632db84f55af85cd4f401d59c6ab29242 (diff)
downloadmariadb-git-cebf9ee2040195a61fbed32d06cc2e335e9f8dfd.tar.gz
Fix various spelling errors still found in code
Reseting -> Resetting Unknow -> Unknown capabilites -> capabilities choosen -> chosen direcory -> directory informations -> information openned -> opened refered -> referred to access -> one to access missmatch -> mismatch succesfully -> successfully dont -> don't
Diffstat (limited to 'sql')
-rw-r--r--sql/log_event_server.cc2
-rw-r--r--sql/multi_range_read.cc16
-rw-r--r--sql/mysqld.cc2
-rw-r--r--sql/opt_subselect.cc2
-rw-r--r--sql/rpl_rli.h2
-rw-r--r--sql/sql_acl.cc2
-rw-r--r--sql/sql_cache.cc12
-rw-r--r--sql/sql_class.cc2
-rw-r--r--sql/sql_partition.cc2
-rw-r--r--sql/sql_repl.cc2
-rw-r--r--sql/sql_select.cc8
-rw-r--r--sql/sql_show.cc4
-rw-r--r--sql/sql_signal.h4
-rw-r--r--sql/table.cc2
-rw-r--r--sql/tztime.cc2
-rw-r--r--sql/udf_example.c4
16 files changed, 34 insertions, 34 deletions
diff --git a/sql/log_event_server.cc b/sql/log_event_server.cc
index 6dee9b9adf6..607d5451134 100644
--- a/sql/log_event_server.cc
+++ b/sql/log_event_server.cc
@@ -5464,7 +5464,7 @@ int Rows_log_event::do_apply_event(rpl_group_info *rgi)
*/
{
- DBUG_PRINT("debug", ("Checking compability of tables to lock - tables_to_lock: %p",
+ DBUG_PRINT("debug", ("Checking compatibility of tables to lock - tables_to_lock: %p",
rgi->tables_to_lock));
/**
diff --git a/sql/mysqld.cc b/sql/mysqld.cc
index c3a4881bde0..306d924b625 100644
--- a/sql/mysqld.cc
+++ b/sql/mysqld.cc
@@ -7671,7 +7671,7 @@ static void usage(void)
It's also needed on some exotic platforms where global variables are
not set to 0 when a program starts.
- We don't need to set variables refered to in my_long_options
+ We don't need to set variables referred to in my_long_options
as these are initialized by my_getopt.
*/
diff --git a/sql/opt_subselect.cc b/sql/opt_subselect.cc
index 0a87d9ccd2f..1c7fe20f12e 100644
--- a/sql/opt_subselect.cc
+++ b/sql/opt_subselect.cc
@@ -2901,7 +2901,7 @@ void advance_sj_state(JOIN *join, table_map remaining_tables, uint idx,
{
DBUG_ASSERT(pos->sj_strategy != sj_strategy);
/*
- If the strategy choosen first time or
+ If the strategy chosen first time or
the strategy replace strategy which was used to exectly the same
tables
*/
diff --git a/sql/rpl_rli.h b/sql/rpl_rli.h
index e3b59aa615c..85e31ef8187 100644
--- a/sql/rpl_rli.h
+++ b/sql/rpl_rli.h
@@ -274,7 +274,7 @@ public:
Needed for problems when slave stops and we want to restart it
skipping one or more events in the master log that have caused
errors, and have been manually applied by DBA already.
- Must be ulong as it's refered to from set_var.cc
+ Must be ulong as it's referred to from set_var.cc
*/
volatile ulonglong slave_skip_counter;
ulonglong max_relay_log_size;
diff --git a/sql/sql_acl.cc b/sql/sql_acl.cc
index 3ec8b9ecfcd..3f6a13778a9 100644
--- a/sql/sql_acl.cc
+++ b/sql/sql_acl.cc
@@ -5023,7 +5023,7 @@ acl_update_proxy_user(ACL_PROXY_USER *new_value, bool is_revoke)
{
if (is_revoke)
{
- DBUG_PRINT("info", ("delting ACL_PROXY_USER"));
+ DBUG_PRINT("info", ("deleting ACL_PROXY_USER"));
delete_dynamic_element(&acl_proxy_users, i);
}
else
diff --git a/sql/sql_cache.cc b/sql/sql_cache.cc
index 57070b038ca..b81dea78bcf 100644
--- a/sql/sql_cache.cc
+++ b/sql/sql_cache.cc
@@ -5128,7 +5128,7 @@ my_bool Query_cache::in_blocks(Query_cache_block * point)
if (block->pprev->pnext != block)
{
DBUG_PRINT("error",
- ("block %p in physical list is incorrect linked, prev block %p refered as next to %p (check from %p)",
+ ("block %p in physical list is incorrect linked, prev block %p referred as next to %p (check from %p)",
block, block->pprev,
block->pprev->pnext,
point));
@@ -5156,7 +5156,7 @@ err1:
if (block->pnext->pprev != block)
{
DBUG_PRINT("error",
- ("block %p in physicel list is incorrect linked, next block %p refered as prev to %p (check from %p)",
+ ("block %p in physicel list is incorrect linked, next block %p referred as prev to %p (check from %p)",
block, block->pnext,
block->pnext->pprev,
point));
@@ -5185,7 +5185,7 @@ my_bool Query_cache::in_list(Query_cache_block * root,
if (block->prev->next != block)
{
DBUG_PRINT("error",
- ("block %p in list '%s' %p is incorrect linked, prev block %p refered as next to %p (check from %p)",
+ ("block %p in list '%s' %p is incorrect linked, prev block %p referred as next to %p (check from %p)",
block, name, root, block->prev,
block->prev->next,
point));
@@ -5214,7 +5214,7 @@ err1:
if (block->next->prev != block)
{
DBUG_PRINT("error",
- ("block %p in list '%s' %p is incorrect linked, next block %p refered as prev to %p (check from %p)",
+ ("block %p in list '%s' %p is incorrect linked, next block %p referred as prev to %p (check from %p)",
block, name, root, block->next,
block->next->prev,
point));
@@ -5256,7 +5256,7 @@ my_bool Query_cache::in_table_list(Query_cache_block_table * root,
if (table->prev->next != table)
{
DBUG_PRINT("error",
- ("table %p(%p) in list '%s' %p(%p) is incorrect linked, prev table %p(%p) refered as next to %p(%p) (check from %p(%p))",
+ ("table %p(%p) in list '%s' %p(%p) is incorrect linked, prev table %p(%p) referred as next to %p(%p) (check from %p(%p))",
table, table->block(), name,
root, root->block(),
table->prev, table->prev->block(),
@@ -5291,7 +5291,7 @@ err1:
if (table->next->prev != table)
{
DBUG_PRINT("error",
- ("table %p(%p) in list '%s' %p(%p) is incorrect linked, next table %p(%p) refered as prev to %p(%p) (check from %p(%p))",
+ ("table %p(%p) in list '%s' %p(%p) is incorrect linked, next table %p(%p) referred as prev to %p(%p) (check from %p(%p))",
table, table->block(),
name, root, root->block(),
table->next, table->next->block(),
diff --git a/sql/sql_class.cc b/sql/sql_class.cc
index 622b0f6c5f5..8a01f1a9ae5 100644
--- a/sql/sql_class.cc
+++ b/sql/sql_class.cc
@@ -3614,7 +3614,7 @@ int select_max_min_finder_subselect::send_data(List<Item> &items)
break;
case ROW_RESULT:
case TIME_RESULT:
- // This case should never be choosen
+ // This case should never be chosen
DBUG_ASSERT(0);
op= 0;
}
diff --git a/sql/sql_partition.cc b/sql/sql_partition.cc
index 3d33731da5c..86ba393fb7b 100644
--- a/sql/sql_partition.cc
+++ b/sql/sql_partition.cc
@@ -41,7 +41,7 @@
which is often referred to as column lists in the code variables. This
enables a user to specify a set of columns and their concatenated value
as the partition value. By comparing the concatenation of these values
- the proper partition can be choosen.
+ the proper partition can be chosen.
*/
/* Some general useful functions */
diff --git a/sql/sql_repl.cc b/sql/sql_repl.cc
index 010ea794254..084259d863d 100644
--- a/sql/sql_repl.cc
+++ b/sql/sql_repl.cc
@@ -1958,7 +1958,7 @@ send_event_to_slave(binlog_send_info *info, Log_event_type event_type,
{
info->error= ER_MASTER_FATAL_ERROR_READING_BINLOG;
return "Failed to replace GTID event with backwards-compatible event: "
- "currupt event.";
+ "corrupt event.";
}
if (!need_dummy)
return NULL;
diff --git a/sql/sql_show.cc b/sql/sql_show.cc
index db7750eedbe..ee4bf6ca7b6 100644
--- a/sql/sql_show.cc
+++ b/sql/sql_show.cc
@@ -1924,7 +1924,7 @@ static void add_table_options(THD *thd, TABLE *table,
packet->append_ulonglong(share->stats_sample_pages);
}
- /* We use CHECKSUM, instead of TABLE_CHECKSUM, for backward compability */
+ /* We use CHECKSUM, instead of TABLE_CHECKSUM, for backward compatibility */
if (create_info.options & HA_OPTION_CHECKSUM)
packet->append(STRING_WITH_LEN(" CHECKSUM=1"));
if (create_info.page_checksum != HA_CHOICE_UNDEF)
@@ -5504,7 +5504,7 @@ static int get_schema_tables_record(THD *thd, TABLE_LIST *tables,
str.qs_append(share->stats_sample_pages);
}
- /* We use CHECKSUM, instead of TABLE_CHECKSUM, for backward compability */
+ /* We use CHECKSUM, instead of TABLE_CHECKSUM, for backward compatibility */
if (share->db_create_options & HA_OPTION_CHECKSUM)
str.qs_append(STRING_WITH_LEN(" checksum=1"));
diff --git a/sql/sql_signal.h b/sql/sql_signal.h
index bf42cdb5f07..433cee21d58 100644
--- a/sql/sql_signal.h
+++ b/sql/sql_signal.h
@@ -77,7 +77,7 @@ public:
/**
Constructor, used to represent a SIGNAL statement.
@param cond the SQL condition to signal (required).
- @param set the collection of signal informations to signal.
+ @param set the collection of signal information to signal.
*/
Sql_cmd_signal(const sp_condition_value *cond,
const Set_signal_information& set)
@@ -104,7 +104,7 @@ public:
/**
Constructor, used to represent a RESIGNAL statement.
@param cond the SQL condition to resignal (optional, may be NULL).
- @param set the collection of signal informations to resignal.
+ @param set the collection of signal information to resignal.
*/
Sql_cmd_resignal(const sp_condition_value *cond,
const Set_signal_information& set)
diff --git a/sql/table.cc b/sql/table.cc
index f4bdbdeac5a..d725e142f80 100644
--- a/sql/table.cc
+++ b/sql/table.cc
@@ -2283,7 +2283,7 @@ int TABLE_SHARE::init_from_binary_frm_image(THD *thd, bool write,
}
else
{
- DBUG_PRINT("info", ("Setting system versioning informations"));
+ DBUG_PRINT("info", ("Setting system versioning information"));
if (init_period_from_extra2(&vers, extra2.system_period.str,
extra2.system_period.str + extra2.system_period.length))
goto err;
diff --git a/sql/tztime.cc b/sql/tztime.cc
index 5a8d6915cec..23c015e4a5e 100644
--- a/sql/tztime.cc
+++ b/sql/tztime.cc
@@ -2564,7 +2564,7 @@ scan_tz_dir(char * name_end, uint symlink_recursion_level, uint verbose)
/*
This is a normal case and not critical. only print warning if
- verbose mode is choosen.
+ verbose mode is chosen.
*/
if (verbose > 0)
{
diff --git a/sql/udf_example.c b/sql/udf_example.c
index e4757de880d..cb3f3ad1c98 100644
--- a/sql/udf_example.c
+++ b/sql/udf_example.c
@@ -972,7 +972,7 @@ avgcost_deinit( UDF_INIT* initid )
}
-/* This is only for MySQL 4.0 compability */
+/* This is only for MySQL 4.0 compatibility */
void
avgcost_reset(UDF_INIT* initid, UDF_ARGS* args, char* is_null, char* message)
{
@@ -1119,7 +1119,7 @@ avg2_deinit( UDF_INIT* initid )
}
-/* This is only for MySQL 4.0 compability */
+/* This is only for MySQL 4.0 compatibility */
void
avg2_reset(UDF_INIT* initid, UDF_ARGS* args, char* is_null, char* message)
{
diff --git a/sql/multi_range_read.cc b/sql/multi_range_read.cc
index ec039962be9..c7c3079f28f 100644
--- a/sql/multi_range_read.cc
+++ b/sql/multi_range_read.cc
@@ -1679,15 +1679,15 @@ ha_rows DsMrr_impl::dsmrr_info(uint keyno, uint n_ranges, uint rows,
if ((*flags & HA_MRR_USE_DEFAULT_IMPL) ||
choose_mrr_impl(keyno, rows, flags, bufsz, cost))
{
- /* Default implementation is choosen */
- DBUG_PRINT("info", ("Default MRR implementation choosen"));
+ /* Default implementation is chosen */
+ DBUG_PRINT("info", ("Default MRR implementation chosen"));
*flags= def_flags;
*bufsz= def_bufsz;
}
else
{
/* *flags and *bufsz were set by choose_mrr_impl */
- DBUG_PRINT("info", ("DS-MRR implementation choosen"));
+ DBUG_PRINT("info", ("DS-MRR implementation chosen"));
}
return 0;
}
@@ -1724,14 +1724,14 @@ ha_rows DsMrr_impl::dsmrr_info_const(uint keyno, RANGE_SEQ_IF *seq,
if ((*flags & HA_MRR_USE_DEFAULT_IMPL) ||
choose_mrr_impl(keyno, rows, flags, bufsz, cost))
{
- DBUG_PRINT("info", ("Default MRR implementation choosen"));
+ DBUG_PRINT("info", ("Default MRR implementation chosen"));
*flags= def_flags;
*bufsz= def_bufsz;
}
else
{
/* *flags and *bufsz were set by choose_mrr_impl */
- DBUG_PRINT("info", ("DS-MRR implementation choosen"));
+ DBUG_PRINT("info", ("DS-MRR implementation chosen"));
}
return rows;
}
@@ -1799,12 +1799,12 @@ bool DsMrr_impl::check_cpk_scan(THD *thd, TABLE_SHARE *share, uint keyno,
@param keyno Index number
@param rows E(full rows to be retrieved)
@param flags IN MRR flags provided by the MRR user
- OUT If DS-MRR is choosen, flags of DS-MRR implementation
+ OUT If DS-MRR is chosen, flags of DS-MRR implementation
else the value is not modified
- @param bufsz IN If DS-MRR is choosen, buffer use of DS-MRR implementation
+ @param bufsz IN If DS-MRR is chosen, buffer use of DS-MRR implementation
else the value is not modified
@param cost IN Cost of default MRR implementation
- OUT If DS-MRR is choosen, cost of DS-MRR scan
+ OUT If DS-MRR is chosen, cost of DS-MRR scan
else the value is not modified
@retval TRUE Default MRR implementation should be used
diff --git a/sql/sql_select.cc b/sql/sql_select.cc
index ba78c77efc9..e52d57c3bbf 100644
--- a/sql/sql_select.cc
+++ b/sql/sql_select.cc
@@ -7702,7 +7702,7 @@ best_access_path(JOIN *join,
Try re-using E(#rows) from "range" optimizer:
We can do so if "range" optimizer used the same intervals as
in (**). The intervals used by range optimizer may be not
- available at this point (as "range" access might have choosen to
+ available at this point (as "range" access might have chosen to
create quick select over another index), so we can't compare
them to (**). We'll make indirect judgements instead.
The sufficient conditions for re-use are:
@@ -11010,7 +11010,7 @@ inline void add_cond_and_fix(THD *thd, Item **e1, Item *e2)
Description of the optimization:
- We look through equalities choosen to perform ref/eq_ref access,
+ We look through equalities chosen to perform ref/eq_ref access,
pick equalities that have form "tbl.part_of_key = othertbl.field"
(where othertbl is a non-const table and othertbl.field may be NULL)
and add them to conditions on correspoding tables (othertbl in this
@@ -17961,7 +17961,7 @@ Field *Item_sum::create_tmp_field(MEM_ROOT *root, bool group, TABLE *table)
new_field= tmp_table_field_from_field_type(root, table);
break;
case ROW_RESULT:
// This case should never be choosen
DBUG_ASSERT(0);
new_field= 0;
break;
@@ -25139,7 +25139,7 @@ void calc_group_buffer(TMP_TABLE_PARAM *param, ORDER *group)
break;
}
default:
/* This case should never be choosen */
DBUG_ASSERT(0);
my_error(ER_OUT_OF_RESOURCES, MYF(ME_FATAL));
}
@@ -17961,7 +17961,7 @@ Field *Item_sum::create_tmp_field(MEM_ROOT *root, bool group, TABLE *table)
break;
case ROW_RESULT:
- // This case should never be choosen
+ // This case should never be chosen
DBUG_ASSERT(0);
new_field= 0;
@@ -25139,7 +25139,7 @@ void calc_group_buffer(TMP_TABLE_PARAM *param, ORDER *group)
}
default:
- /* This case should never be choosen */
+ /* This case should never be chosen */
DBUG_ASSERT(0);
my_error(ER_OUT_OF_RESOURCES, MYF(ME_FATAL));